@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::ContainerWidget);
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::LogAny - log message rendering
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 0.004
 
 =head1 DESCRIPTION
 
-Provides basic log rendering, with optional warn() / STDERR capture.
+Provides basic log rendering, with optional C<warn> / C<STDERR> capture.
 
 =begin HTML
 
@@ -71,6 +71,8 @@ use Variable::Disposition qw(dispose retain retain_future);
 use POSIX qw(strftime);
 use Text::Wrap (); 
 
+use Syntax::Keyword::Try;
+
 use Tickit::Utils qw(textwidth substrwidth);
 use Tickit::Style;
 use Tickit::Widget::Table;
@@ -161,6 +163,7 @@ sub new {
 			width => 23,
 			transform => sub {
 				my ($row, $col, $cell) = @_;
+				return Future->done('') unless defined $cell && length $cell;
 				my @date = $self->get_style_pen('date')->getattrs;
 				my @date_sep = $self->get_style_pen('date_sep')->getattrs;
 				my @time = $self->get_style_pen('time')->getattrs;
@@ -190,7 +193,7 @@ sub new {
 			width => 9,
 			transform => sub {
 				my ($row, $col, $cell) = @_;
-				$self->{severity_style}{$cell}
+				$self->{severity_style}{$cell} // Future->done('')
 			}
 		}, {
 			label => 'Category',
@@ -345,10 +348,14 @@ sub show_stacktrace {
 					$cleanup->();
 					1
 				} or warn "Failed to do cleanup - $@";
-				
+
+				$win->close;
 				$win->tickit->later(sub {
-					eval { dispose $holder; 1 }
-						or warn "Failed to dispose vbox - $@";
+					try {
+						dispose $holder;
+					} catch {
+						warn "Failed to dispose vbox - $@";
+					}
 				});
 			}
 		)
@@ -379,13 +386,15 @@ sub stacktrace_holder_widget {
 		);
 		$panel->add($vbox);
 		$cleanup = sub {
-			eval {
-				$panel->close;
-				dispose $panel;
-				1;
-			} or do {
-				warn "Failed - $@";
-			};
+			$panel->close;
+			$win->tickit->later(sub {
+				try {
+					dispose $vbox;
+					dispose $panel;
+				} catch {
+					warn "Failed - $@";
+				}
+			});
 			$win->expose;
 		};
 	} else {
@@ -412,10 +421,15 @@ sub stacktrace_holder_widget {
 		# We're responsible for disposing the $frame object, since we retained
 		# it earlier.
 		$cleanup = sub {
+			$frame->set_window(undef);
 			$float->close;
 			$win->tickit->later(sub {
-				eval { dispose $frame; 1 }
-					or warn "Failed to dispose frame - $@";
+				try {
+					dispose $frame;
+					dispose $vbox;
+				} catch {
+					warn "Failed to dispose frame - $@";
+				}
 				$win->expose;
 			})
 		};
@@ -441,7 +455,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
